@@ -152,7 +152,6 @@ from . import adapter_tasteofpoisoninkubationnet
 from . import adapter_thedelphicexpansecom
 from . import adapter_thundercatsfansorg
 from . import adapter_wwwaneroticstorycom
-from . import adapter_gravitytalescom
 from . import adapter_lcfanficcom
 from . import adapter_noveltrovecom
 from . import adapter_inkbunnynet
@@ -170,6 +169,7 @@ from . import adapter_archivehpfanfictalkcom
 from . import adapter_scifistoriescom
 from . import adapter_silmarillionwritersguildorg
 from . import adapter_chireadscom
+from . import adapter_scribblehubcom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
