@@ -44,16 +44,16 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
         storyId = self.parsedUrl.path.split('/',)[2]
         # replace later chapters with first chapter but don't remove numbers
         # from the URL that disambiguate stories with the same title.
-        storyId = re.sub("-ch-?\d\d", "", storyId)
+        storyId = re.sub(r"-ch-?\d\d", "", storyId)
         self.story.setMetadata('storyId', storyId)
 
-        ## accept m(mobile)url, but use www.
-        url = re.sub("^(www|german|spanish|french|dutch|italian|romanian|portuguese|other)\.i",
-                              "\1",
-                              url)
+        ## normalize to www.literotica.com.
+        url = re.sub(r"^(https?://)(www|german|spanish|french|dutch|italian|romanian|portuguese|other)(\.i)?",
+                     r"\1www",
+                     url)
 
         ## strip ?page=...
-        url = re.sub("\?page=.*$", "", url)
+        url = re.sub(r"\?page=.*$", "", url)
 
         ## set url
         self._setURL(url)
@@ -212,7 +212,7 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
             seriesTr = urlTr.previousSibling
             while 'ser-ttl' not in seriesTr['class']:
                 seriesTr = seriesTr.previousSibling
-            m = re.match("^(?P<title>.*?):\s(?P<numChapters>\d+)\sPart\sSeries$", seriesTr.find("strong").text)
+            m = re.match(r"^(?P<title>.*?):\s(?P<numChapters>\d+)\sPart\sSeries$", seriesTr.find("strong").text)
             self.story.setMetadata('title', m.group('title'))
             seriesTitle = m.group('title')
 
@@ -232,7 +232,7 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
                 pub_date = makeDate(chapterTr.findAll('td')[-1].text, self.dateformat)
                 dates.append(pub_date)
                 chapterTr = chapterTr.nextSibling
-                
+
                 chapter_title = chapterLink.text
                 if self.getConfig("clean_chapter_titles"):
                     logger.debug('\tChapter Name: "%s"' % chapterLink.string)
@@ -261,7 +261,7 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
                                     chapter_title = 'Part %s' % chapter
                             elif separater_char in [":", "-"]:
                                 chapter_title = chapter
-    
+
                 # pages include full URLs.
                 chapurl = chapterLink['href']
                 if chapurl.startswith('//'):
@@ -337,7 +337,7 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
         pages = page_soup.find('select', {'name' : 'page'})
         page_nums = [page.text for page in pages.findAll('option')] if pages else 0
 
-        fullhtml = "" 
+        fullhtml = ""
         self.getCategories(page_soup)
         chapter_description = ''
         if self.getConfig("description_in_chapter"):
@@ -351,7 +351,7 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
                 logger.debug("page_url= %s" % page_url)
                 raw_page = self._fetchUrl(page_url)
                 fullhtml += self.getPageText(raw_page, url)
-        
+
 #         logger.debug(fullhtml)
         page_soup = self.make_soup(fullhtml)
         fullhtml = self.utf8FromSoup(url, self.make_soup(fullhtml))
@@ -363,6 +363,3 @@ class LiteroticaSiteAdapter(BaseSiteAdapter):
 
 def getClass():
     return LiteroticaSiteAdapter
-
-
-
