@@ -23,6 +23,11 @@ import codecs
 from . import six
 from .six.moves import configparser
 from .six.moves.configparser import DEFAULTSECT, MissingSectionHeaderError, ParsingError
+if six.PY2:
+  ConfigParser = configparser.SafeConfigParser
+else: # PY3
+  ConfigParser = configparser.ConfigParser
+
 from .six.moves import urllib
 from .six.moves.urllib.parse import (urlencode, quote_plus)
 from .six.moves.urllib.request import (build_opener, HTTPCookieProcessor, Request)
@@ -32,6 +37,7 @@ from .six import text_type as unicode
 from .six import string_types as basestring
 from .six import ensure_binary, ensure_text
 
+
 import time
 import logging
 import sys
@@ -519,11 +525,11 @@ def make_generate_cover_settings(param):
     return vlist
 
 
-class Configuration(configparser.SafeConfigParser):
+class Configuration(ConfigParser):
 
     def __init__(self, sections, fileform, lightweight=False):
         site = sections[-1] # first section is site DN.
-        configparser.SafeConfigParser.__init__(self)
+        ConfigParser.__init__(self)
 
         self.lightweight = lightweight
         self.use_pagecache = False # default to false for old adapters.
@@ -584,7 +590,7 @@ class Configuration(configparser.SafeConfigParser):
             self._sections = self._dict((section_url_f(k) if (domain in k and 'http' in k) else k, v) for k, v in six.viewitems(self._sections))
             # logger.debug(self._sections.keys())
         except Exception as e:
-            logger.warn("Failed to perform section_url_names: %s"%e)
+            logger.warning("Failed to perform section_url_names: %s"%e)
 
     def addUrlConfigSection(self,url):
         if not self.lightweight: # don't need when just checking for normalized URL.
@@ -665,7 +671,7 @@ class Configuration(configparser.SafeConfigParser):
                 except:
                     pass
             if not file_val:
-                logger.warn("All files for (%s) failed!  Using (%s) instead. Filelist: (%s)"%
+                logger.warning("All files for (%s) failed!  Using (%s) instead. Filelist: (%s)"%
                             (key+"_filelist",key,val_files))
 
         if not file_val:
@@ -692,7 +698,7 @@ class Configuration(configparser.SafeConfigParser):
     # split and strip each.
     def get_config_list(self, sections, key, default=[]):
         vlist = re.split(r'(?<!\\),',self.get_config(sections,key)) # don't split on \,
-        vlist = [x for x in [ v.strip().replace('\,',',') for v in vlist ] if x !='']
+        vlist = [x for x in [ v.strip().replace(r'\,',',') for v in vlist ] if x !='']
         #print("vlist("+key+"):"+unicode(vlist))
         if not vlist:
             return default
@@ -1034,7 +1040,7 @@ class Configuration(configparser.SafeConfigParser):
             try:
                 return reduce_zalgo(data,max_zalgo)
             except Exception as e:
-                logger.warn("reduce_zalgo failed(%s), continuing."%e)
+                logger.warning("reduce_zalgo failed(%s), continuing."%e)
         return data
 
     # Assumes application/x-www-form-urlencoded.  parameters, headers are dict()s
