@@ -40,8 +40,8 @@ from .htmlcleanup import conditionalRemoveEntities, removeEntities, removeAllEnt
 from .configurable import Configurable, re_compile
 from .htmlheuristics import was_run_marker
 
-SPACE_REPLACE=u'\s'
-SPLIT_META=u'\,'
+SPACE_REPLACE=r'\s'
+SPLIT_META=r'\,'
 
 # Create convert_image method depending on which graphics lib we can
 # load.  Preferred: calibre, PIL, none
@@ -99,7 +99,7 @@ try:
         if export:
             return (img.export(convtype[imgtype]),imgtype,imagetypes[imgtype])
         else:
-            logger.debug("image used unchanged")
+            # logger.debug("image used unchanged")
             return (data,imgtype,imagetypes[imgtype])
 
 except:
@@ -171,7 +171,7 @@ def no_convert_image(url,data):
         # parameter.
         ext = url[url.rfind('.')+1:].lower()
         if ext not in imagetypes:
-            logger.debug("no_convert_image url:%s - no known extension -- using .jpg"%url)
+            logger.info("no_convert_image url:%s - no known extension -- using .jpg"%url)
             # doesn't have extension? use jpg.
             ext='jpg'
 
@@ -212,7 +212,7 @@ except:
     def sanitize_comments_html(t):
         ## should only be called by Calibre version, so this shouldn't
         ## trip.
-        logger.debug("fake sanitize called...")
+        # logger.debug("fake sanitize called...")
         return t
 
 # The list comes from ffnet, the only multi-language site we support
@@ -765,7 +765,7 @@ class Story(Configurable):
                     try:
                         value = commaGroups(unicode(value))
                     except Exception as e:
-                        logger.warn("Failed to add commas to %s value:(%s) exception(%s)"%(key,value,e))
+                        logger.warning("Failed to add commas to %s value:(%s) exception(%s)"%(key,value,e))
                 if key in ("dateCreated"):
                     value = value.strftime(self.getConfig(key+"_format","%Y-%m-%d %H:%M:%S"))
                 if key in ("datePublished","dateUpdated"):
@@ -1275,7 +1275,7 @@ class Story(Configurable):
                 if sizes:
                     owidth, oheight = get_image_size(data)
                     cover_big_enough = owidth >= sizes[0] and oheight >= sizes[1]
-                    logger.debug("cover_big_enough:%s %s>=%s, %s>=%s"%(cover_big_enough,owidth,sizes[0],oheight,sizes[1]))
+                    # logger.debug("cover_big_enough:%s %s>=%s, %s>=%s"%(cover_big_enough,owidth,sizes[0],oheight,sizes[1]))
             except Exception as e:
                 raise exceptions.FailedToDownload("Failed to process cover_min_size from personal.ini:%s\nException: %s"%(self.getConfigList('cover_min_size'),e))
 
