@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Fanficdownloader team, 2019 FanFicFare team
+# Copyright 2011 Fanficdownloader team, 2020 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -60,7 +60,7 @@ class EpubWriter(BaseStoryWriter):
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>${title} by ${author}</title>
-<link href="stylesheet.css" type="text/css" charset="UTF-8" rel="stylesheet"/>
+<link href="stylesheet.css" type="text/css" rel="stylesheet"/>
 </head>
 <body class="fff_titlepage">
 <h3><a href="${storyUrl}">${title}</a> by ${authorHTML}</h3>
@@ -86,7 +86,7 @@ ${value}<br />
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>${title} by ${author}</title>
-<link href="stylesheet.css" type="text/css" charset="UTF-8" rel="stylesheet"/>
+<link href="stylesheet.css" type="text/css" rel="stylesheet"/>
 </head>
 <body class="fff_titlepage">
 <h3><a href="${storyUrl}">${title}</a> by ${authorHTML}</h3>
@@ -116,7 +116,7 @@ ${value}<br />
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>${title} by ${author}</title>
-<link href="stylesheet.css" type="text/css" charset="UTF-8" rel="stylesheet"/>
+<link href="stylesheet.css" type="text/css" rel="stylesheet"/>
 </head>
 <body class="fff_tocpage">
 <div>
@@ -137,11 +137,11 @@ ${value}<br />
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>${chapter}</title>
-<link href="stylesheet.css" type="text/css" charset="UTF-8" rel="stylesheet"/>
-<meta name="chapterurl" content="${url}"></meta>
-<meta name="chapterorigtitle" content="${origchapter}"></meta>
-<meta name="chaptertoctitle" content="${tocchapter}"></meta>
-<meta name="chaptertitle" content="${chapter}"></meta>
+<link href="stylesheet.css" type="text/css" rel="stylesheet"/>
+<meta name="chapterurl" content="${url}" />
+<meta name="chapterorigtitle" content="${origchapter}" />
+<meta name="chaptertoctitle" content="${tocchapter}" />
+<meta name="chaptertitle" content="${chapter}" />
 </head>
 <body class="fff_chapter">
 <h3 class="fff_chapter_title">${chapter}</h3>
@@ -156,7 +156,7 @@ ${value}<br />
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>Update Log</title>
-<link href="stylesheet.css" type="text/css" charset="UTF-8" rel="stylesheet"/>
+<link href="stylesheet.css" type="text/css" rel="stylesheet"/>
 </head>
 <body class="fff_logpage">
 <h3>Update Log</h3>
@@ -171,7 +171,8 @@ ${value}<br />
 ''')
 
         self.EPUB_LOG_UPDATE_END = string.Template('''
-</p><hr />
+</p>
+<hr/>
 ''')
 
         self.EPUB_LOG_PAGE_END = string.Template('''
@@ -352,7 +353,13 @@ div { margin: 0pt; padding: 0pt; }
 
         contentdom = getDOMImplementation().createDocument(None, "package", None)
         package = contentdom.documentElement
-        package.setAttribute("version","2.0")
+        ## might want 3.1 or something in future.
+        epub3 = self.getConfig("epub_version",default="2.0").startswith("3")
+        if epub3:
+            package.setAttribute("version","3.0")
+        else:
+            package.setAttribute("version","2.0")
+        logger.info("Saving EPUB Version "+package.getAttribute("version"))
         package.setAttribute("xmlns","http://www.idpf.org/2007/opf")
         package.setAttribute("unique-identifier","fanficfare-uid")
         metadata=newTag(contentdom,"metadata",
@@ -365,45 +372,65 @@ div { margin: 0pt; padding: 0pt; }
                                     attrs={"id":"fanficfare-uid"}))
 
         if self.getMetadata('title'):
-            metadata.appendChild(newTag(contentdom,"dc:title",text=self.getMetadata('title')))
+            metadata.appendChild(newTag(contentdom,"dc:title",text=self.getMetadata('title'),
+                                        attrs={"id":"id"}))
 
+        def creator_attrs(idnum):
+            if epub3:
+                return {"id":"id-%d"%idnum}
+            else:
+                return {"opf:role":"aut"}
+        idnum = 1
         if self.getMetadata('author'):
             if self.story.isList('author'):
                 for auth in self.story.getList('author'):
                     metadata.appendChild(newTag(contentdom,"dc:creator",
-                                                attrs={"opf:role":"aut"},
+                                                attrs=creator_attrs(idnum),
                                                 text=auth))
+                    idnum += 1
             else:
                 metadata.appendChild(newTag(contentdom,"dc:creator",
-                                            attrs={"opf:role":"aut"},
+                                            attrs=creator_attrs(idnum),
                                             text=self.getMetadata('author')))
+                idnum += 1
 
-        metadata.appendChild(newTag(contentdom,"dc:contributor",text="FanFicFare [https://github.com/JimmXinu/FanFicFare]",attrs={"opf:role":"bkp"}))
-        metadata.appendChild(newTag(contentdom,"dc:rights",text=""))
+        metadata.appendChild(newTag(contentdom,"dc:contributor",text="FanFicFare [https://github.com/JimmXinu/FanFicFare]",
+                                    attrs={"id":"id-%d"%idnum}))
+        idnum += 1
+        # metadata.appendChild(newTag(contentdom,"dc:rights",text=""))
         if self.story.getMetadata('langcode'):
-            metadata.appendChild(newTag(contentdom,"dc:language",text=self.story.getMetadata('langcode')))
+            langcode=self.story.getMetadata('langcode')
         else:
-            metadata.appendChild(newTag(contentdom,"dc:language",text='en'))
+            langcode='en'
+        metadata.appendChild(newTag(contentdom,"dc:language",text=langcode))
 
         #  published, created, updated, calibre
         #  Leave calling self.story.getMetadataRaw directly in case date format changes.
-        if self.story.getMetadataRaw('datePublished'):
-            metadata.appendChild(newTag(contentdom,"dc:date",
-                                        attrs={"opf:event":"publication"},
-                                        text=self.story.getMetadataRaw('datePublished').strftime("%Y-%m-%d")))
-
-        if self.story.getMetadataRaw('dateCreated'):
-            metadata.appendChild(newTag(contentdom,"dc:date",
-                                        attrs={"opf:event":"creation"},
-                                        text=self.story.getMetadataRaw('dateCreated').strftime("%Y-%m-%d")))
-
-        if self.story.getMetadataRaw('dateUpdated'):
-            metadata.appendChild(newTag(contentdom,"dc:date",
-                                        attrs={"opf:event":"modification"},
-                                        text=self.story.getMetadataRaw('dateUpdated').strftime("%Y-%m-%d")))
+        if epub3:
+            ## epub3 requires an updated modified date on every change of
+            ## any kind, not just *content* change.
+            from datetime import datetime
             metadata.appendChild(newTag(contentdom,"meta",
-                                        attrs={"name":"calibre:timestamp",
-                                               "content":self.story.getMetadataRaw('dateUpdated').strftime("%Y-%m-%dT%H:%M:%S")}))
+                                        attrs={"property":"dcterms:modified"},
+                                        text=datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")))
+        else:
+            if self.story.getMetadataRaw('datePublished'):
+                metadata.appendChild(newTag(contentdom,"dc:date",
+                                            attrs={"opf:event":"publication"},
+                                            text=self.story.getMetadataRaw('datePublished').strftime("%Y-%m-%d")))
+
+            if self.story.getMetadataRaw('dateCreated'):
+                metadata.appendChild(newTag(contentdom,"dc:date",
+                                            attrs={"opf:event":"creation"},
+                                            text=self.story.getMetadataRaw('dateCreated').strftime("%Y-%m-%d")))
+
+            if self.story.getMetadataRaw('dateUpdated'):
+                metadata.appendChild(newTag(contentdom,"dc:date",
+                                            attrs={"opf:event":"modification"},
+                                            text=self.story.getMetadataRaw('dateUpdated').strftime("%Y-%m-%d")))
+                metadata.appendChild(newTag(contentdom,"meta",
+                                            attrs={"name":"calibre:timestamp",
+                                                   "content":self.story.getMetadataRaw('dateUpdated').strftime("%Y-%m-%dT%H:%M:%S")}))
 
         series = self.story.getMetadataRaw('series')
         if series and self.getConfig('calibre_series_meta'):
@@ -440,12 +467,43 @@ div { margin: 0pt; padding: 0pt; }
                                         text=self.getMetadata('site')))
 
         if self.getMetadata('storyUrl'):
-            metadata.appendChild(newTag(contentdom,"dc:identifier",
-                                        attrs={"opf:scheme":"URL"},
-                                        text=self.getMetadata('storyUrl')))
+            if epub3:
+                metadata.appendChild(newTag(contentdom,"dc:identifier",
+                                            text="URL:"+self.getMetadata('storyUrl')))
+            else:
+                metadata.appendChild(newTag(contentdom,"dc:identifier",
+                                            attrs={"opf:scheme":"URL"},
+                                            text=self.getMetadata('storyUrl')))
             metadata.appendChild(newTag(contentdom,"dc:source",
                                         text=self.getMetadata('storyUrl')))
 
+        if epub3:
+            # <meta refines="#id" property="title-type">main</meta>
+            metadata.appendChild(newTag(contentdom,"meta",
+                                        attrs={"property":"title-type",
+                                               "refines":"#id",
+                                               },
+                                        text="main"))
+
+            # epub3 removes attrs that identify dc:creator and
+            # dc:contributor types and instead put them here.
+            # 'aut' for 1-(idnum-1)
+            for j in range(1,idnum-1):
+                #<meta property="role" refines="#id-1" scheme="marc:relators">aut</meta>
+                metadata.appendChild(newTag(contentdom,"meta",
+                                            attrs={"property":"role",
+                                                   "refines":"#id-%d"%j,
+                                                   "scheme":"marc:relators",
+                                                   },
+                                            text="aut"))
+
+            metadata.appendChild(newTag(contentdom,"meta",
+                                        attrs={"property":"role",
+                                               "refines":"#id-%d"%(idnum-1),
+                                               "scheme":"marc:relators",
+                                               },
+                                        text="bkp"))
+
         ## end of metadata, create manifest.
         items = [] # list of (id, href, type, title) tuples(all strings)
         itemrefs = [] # list of strings -- idrefs from .opfs' spines
@@ -568,6 +626,16 @@ div { margin: 0pt; padding: 0pt; }
                                         attrs={'id':id,
                                                'href':href,
                                                'media-type':type}))
+        if epub3:
+            # epub3 nav
+            # <item href="nav.xhtml" id="nav" media-type="application/xhtml+xml" properties="nav"/>
+            manifest.appendChild(newTag(contentdom,"item",
+                                        attrs={'href':'nav.xhtml',
+                                               'id':'nav',
+                                               'media-type':'application/xhtml+xml',
+                                               'properties':'nav'
+                                               }))
+
 
         spine = newTag(contentdom,"spine",attrs={"toc":"ncx"})
         package.appendChild(spine)
@@ -640,6 +708,69 @@ div { margin: 0pt; padding: 0pt; }
         tocncxdom.unlink()
         del tocncxdom
 
+        if epub3:
+            ##############################################################################################################
+            ## create nav.xhtml file
+            tocnavdom = getDOMImplementation().createDocument(None, "html", None)
+            navxhtml = tocnavdom.documentElement
+            navxhtml.setAttribute("xmlns","http://www.w3.org/1999/xhtml")
+            navxhtml.setAttribute("xmlns:epub","http://www.idpf.org/2007/ops")
+            navxhtml.setAttribute("lang",langcode)
+            navxhtml.setAttribute("xml:lang",langcode)
+            head = tocnavdom.createElement("head")
+            navxhtml.appendChild(head)
+            head.appendChild(newTag(tocnavdom,"title",text="Navigation"))
+            # <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
+            head.appendChild(newTag(tocnavdom,"meta",
+                                    attrs={"http-equiv":"Content-Type",
+                                           "content":"text/html; charset=utf-8"}))
+
+            body = tocnavdom.createElement("body")
+            navxhtml.appendChild(body)
+            nav = newTag(tocnavdom,"nav",
+                         attrs={"epub:type":"toc"})
+            body.appendChild(nav)
+            ol = newTag(tocnavdom,"ol")
+            nav.appendChild(ol)
+
+            for item in items:
+                (id,href,type,title)=item
+                # only items to be skipped, cover.xhtml, images, toc.nav,
+                # stylesheet.css, should have no title.
+                if title:
+                    li = newTag(tocnavdom,"li")
+                    ol.appendChild(li)
+                    atag = newTag(tocnavdom,"a",
+                                  attrs={"href":href},
+                                  text=stripHTML(title))
+                    li.appendChild(atag)
+
+            if self.story.cover:
+                # <nav epub:type="landmarks" hidden="">
+                #   <ol>
+                #     <li><a href="OEBPS/cover.xhtml" epub:type="cover">Cover</a></li>
+                #   </ol>
+                # </nav>
+                nav = newTag(tocnavdom,"nav",
+                             attrs={"epub:type":"landmarks",
+                                    "hidden":""})
+                body.appendChild(nav)
+                ol = newTag(tocnavdom,"ol")
+                nav.appendChild(ol)
+                li = newTag(tocnavdom,"li")
+                ol.appendChild(li)
+                atag = newTag(tocnavdom,"a",
+                              attrs={"href":"OEBPS/cover.xhtml",
+                                     "epub:type":"cover"},
+                              text="Cover")
+                li.appendChild(atag)
+
+            # write nav.xhtml to zip file
+            outputepub.writestr("nav.xhtml",tocnavdom.toxml(encoding='utf-8'))
+            tocnavdom.unlink()
+            del tocnavdom
+            ##############################################################################################################
+
         # write stylesheet.css file.
         outputepub.writestr("OEBPS/stylesheet.css",self.EPUB_CSS.substitute(self.story.getAllMetadata()))
 
